summaryrefslogtreecommitdiff
path: root/drivers/media/platform/vsp1/vsp1_drm.h
diff options
context:
space:
mode:
authorLaurent Pinchart <laurent.pinchart+renesas@ideasonboard.com>2018-02-26 11:06:21 -0500
committerMauro Carvalho Chehab <mchehab+samsung@kernel.org>2018-05-04 08:06:29 -0400
commitcbb7fa49c7466b19e984f3c87d2a07f5b56a1764 (patch)
tree2ddcd94ca0ff10dadd8995d33952fbe40b48351e /drivers/media/platform/vsp1/vsp1_drm.h
parentdc3eaba4ee3debc1baa4a0e148cc7521f45d773b (diff)
media: v4l: vsp1: Rename BRU to BRx
Some VSP instances have two blending units named BRU (Blend/ROP Unit) and BRS (Blend/ROP Sub unit). The BRS is a smaller version of the BRU with only two inputs, but otherwise offers similar features and offers the same register interface. The BRU and BRS can be used exchangeably in VSP pipelines (provided no more than two inputs are needed). Due to historical reasons, the VSP1 driver implements support for both the BRU and BRS through objects named vsp1_bru. The code uses the name BRU to refer to either the BRU or the BRS, except in a few places where noted explicitly. This creates confusion. In an effort to avoid confusion, rename the vsp1_bru object and the corresponding API to vsp1_brx, and use BRx to refer to blend unit instances regardless of their type. The names BRU and BRS are retained where reference to a particular blend unit type is needed, as well as in hardware registers to stay close to the datasheet. Signed-off-by: Laurent Pinchart <laurent.pinchart+renesas@ideasonboard.com> Acked-by: Kieran Bingham <kieran.bingham+renesas@ideasonboard.com> Signed-off-by: Mauro Carvalho Chehab <mchehab+samsung@kernel.org>
Diffstat (limited to 'drivers/media/platform/vsp1/vsp1_drm.h')
-rw-r--r--drivers/media/platform/vsp1/vsp1_drm.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/media/platform/vsp1/vsp1_drm.h b/drivers/media/platform/vsp1/vsp1_drm.h
index c84bc1c456c0..d738cc57f0e3 100644
--- a/drivers/media/platform/vsp1/vsp1_drm.h
+++ b/drivers/media/platform/vsp1/vsp1_drm.h
@@ -24,8 +24,8 @@
* @pipe: the VSP1 pipeline used for display
* @width: output display width
* @height: output display height
* @force_bru_release: when set, release the BRU during the next reconfiguration
* @wait_queue: wait queue to wait for BRU release completion
* @du_complete: frame completion callback for the DU driver (optional)
* @du_private: data to be passed to the du_complete callback
*/
@@ -35,7 +35,7 @@ struct vsp1_drm_pipeline {
unsigned int width;
unsigned int height;
- bool force_bru_release;
+ bool force_brx_release;
wait_queue_head_t wait_queue;
/* Frame synchronisation */
@@ -24,8 +24,8 @@
* @width: output display width
* @height: output display height
- * @force_bru_release: when set, release the BRU during the next reconfiguration
- * @wait_queue: wait queue to wait for BRU release completion
+ * @force_brx_release: when set, release the BRx during the next reconfiguration
+ * @wait_queue: wait queue to wait for BRx release completion
* @du_complete: frame completion callback for the DU driver (optional)
* @du_private: data to be passed to the du_complete callback